@@ -153,6 +153,9 @@ class TestOrganizationNameCleaver(unittest.TestCase):
     def test_handles_empty_names(self):
         self.assertEqual('', str(OrganizationNameCleaver('').parse()))
 
+    def test_coca_cola_bottling_co_of_new_england(self):
+        self.assertEqual('', str(OrganizationNameCleaver('COCA-COLA BOTTLING CO OF NEW ENGLAND').parse()))
+
 
 
 class TestIndividualNameCleaver(unittest.TestCase):
